Contains parser and compiler options passed to pomsky.

Structs

Options passed to the pomsky compiler

Options passed to the pomsky parser

Enums

A regex flavor is a regex engine or a set of regex engines that are similar enough that they can be treated the same for the purpose of writing regexes.